@@ -924,6 +924,7 @@ class InputHipimsSub(InputHipims):
         super().__init__(dem_data, num_of_sections, case_folder)
 
 #%% ===================================Static method===========================
+
 def _cell_subs_convertor(input_cell_subs, header_global,
                          header_local, to_global=True):
     """
@@ -1231,8 +1232,6 @@ def save_object(obj, file_name, compression=True):
     """ Save the object
     """
     # Overwrites any existing file.
-    if not file_name.endswith('.pickle'):
-        file_name = file_name+'.pickle'
     if compression:
         with gzip.open(file_name, 'wb') as output_file:
             pickle.dump(obj, output_file, pickle.HIGHEST_PROTOCOL)
