@@ -266,7 +266,7 @@ class Raster(object):
                                             (grid_x, grid_y), method=method)
         return array_interp
     
-    def grid_resample(self, newsize):
+    def grid_resample_nearest(self, newsize):
         """
         resample a grid to a new grid resolution via nearest interpolation
         """
@@ -414,8 +414,9 @@ class Raster(object):
         figsize: the size of map
         dpi: The resolution in dots per inch
         vmin and vmax define the data range that the colormap covers
-        figname=None, figsize=None, dpi=300, vmin=None, vmax=None, 
-                cax=True, dem_array=None, relocate=False, scale_ratio=1
+        cax_str: string as the title of the colorbar
+        relocate: relocate the origin of the grid coordinates to (0, 0)
+        scale_ratio: 1|1000, axis unit 1 m or 1000 meter
         """
         fig, ax = gs.mapshow(raster_obj=self, **kwargs)
         return fig, ax
